@@ -3,8 +3,6 @@
 import Control.Exception
 import Control.Monad
 import Data.Aeson
-import Data.Aeson.Encode
-import Data.Aeson.Parser
 import Data.Attoparsec
 import Data.Time.Clock
 import System.Environment (getArgs)
